mailr18416 - in /branches/frame_order_testing: ./ gui/analyses/auto_model_free.py test_suite/gui_tests/model_free.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on February 05, 2013 - 08:29:
Author: bugman
Date: Tue Feb  5 08:29:52 2013
New Revision: 18416

URL: http://svn.gna.org/viewcvs/relax?rev=18416&view=rev
Log:
Merged revisions 18414-18415 via svnmerge from 
svn+ssh://bugman@xxxxxxxxxxx/svn/relax/trunk

........
  r18414 | bugman | 2013-02-04 22:34:03 +0100 (Mon, 04 Feb 2013) | 9 lines
  
  Fix for bug #20479 - the failure of non-fully automated model-free analyses 
in the GUI.
  
  This bug was reported by Stanislava Panova (https://gna.org/users/stacy) at
  https://gna.org/bugs/?20479.
  
  The problem is GUI specific and was when running each diffusion model one 
after the other.  The GUI
  was setting the base data pipe to the 'final' data pipe, which is a clear 
error.
........
  r18415 | bugman | 2013-02-05 08:11:15 +0100 (Tue, 05 Feb 2013) | 3 lines
  
  Added spherical diffusion to the optimisation in the 
Mf.test_bug_20479_gui_final_pipe GUI test.
........

Modified:
    branches/frame_order_testing/   (props changed)
    branches/frame_order_testing/gui/analyses/auto_model_free.py
    branches/frame_order_testing/test_suite/gui_tests/model_free.py

Propchange: branches/frame_order_testing/
------------------------------------------------------------------------------
--- svnmerge-integrated (original)
+++ svnmerge-integrated Tue Feb  5 08:29:52 2013
@@ -1,1 +1,1 @@
-/trunk:1-18412
+/trunk:1-18415

Modified: branches/frame_order_testing/gui/analyses/auto_model_free.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/frame_order_testing/gui/analyses/auto_model_free.py?rev=18416&r1=18415&r2=18416&view=diff
==============================================================================
--- branches/frame_order_testing/gui/analyses/auto_model_free.py (original)
+++ branches/frame_order_testing/gui/analyses/auto_model_free.py Tue Feb  5 
08:29:52 2013
@@ -806,9 +806,6 @@
 
         # Start the protocol.
         dauvergne_protocol.dAuvergne_protocol(pipe_name=self.data.pipe_name, 
pipe_bundle=self.data.pipe_bundle, results_dir=self.data.save_dir, 
diff_model=self.data.global_models, mf_models=self.data.mf_models, 
local_tm_models=self.data.local_tm_models, grid_inc=self.data.inc, 
diff_tensor_grid_inc=self.data.diff_tensor_grid_inc, 
mc_sim_num=self.data.mc_sim_num, max_iter=self.data.max_iter, 
conv_loop=self.data.conv_loop)
-
-        # Once completed, change the main pipe of the analysis to the final 
data pipe.
-        ds.relax_gui.analyses[self.data_index].pipe_name = 'final'
 
 
 

Modified: branches/frame_order_testing/test_suite/gui_tests/model_free.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/frame_order_testing/test_suite/gui_tests/model_free.py?rev=18416&r1=18415&r2=18416&view=diff
==============================================================================
--- branches/frame_order_testing/test_suite/gui_tests/model_free.py (original)
+++ branches/frame_order_testing/test_suite/gui_tests/model_free.py Tue Feb  
5 08:29:52 2013
@@ -164,8 +164,8 @@
         auto_model_free.dauvergne_protocol.dAuvergne_protocol.opt_func_tol = 
1e-5
         
auto_model_free.dauvergne_protocol.dAuvergne_protocol.opt_max_iterations = 
1000
 
-        # Execute the 'local_tm' and 'final' protocol stages sequentially.
-        for protocol in ['local_tm', 'final']:
+        # Execute the 'local_tm', 'sphere' and 'final' protocol stages 
sequentially.
+        for protocol in ['local_tm', 'sphere', 'final']:
             # Set the protocol mode.
             if protocol == 'local_tm':
                 analysis.mode_win.select_local_tm()




Related Messages


Powered by MHonArc, Updated Tue Feb 05 09:00:02 2013